Learn R Programming

tidyextreme (version 1.0.0)

calculate_TN0: Calculate number of days with temperature < 0\(^\circ\)C

Description

Counts the number of days per year when daily temperature is less than 0\(^\circ\)C.

Usage

calculate_TN0(
  df,
  frequency = "daily",
  time_col = NULL,
  tmin_col = NULL,
  temp_col = NULL
)

Value

A tibble with columns: year, TN0

Arguments

df

Data frame with climate data

frequency

Temporal frequency: "daily" or "hourly" (string)

time_col

Name of the time column (string). For daily frequency, the column should be of class Date or a string in the format YYYY-MM-DD. For hourly frequency, the column should be of class POSIXct or a string in the format YYYY-MM-DD HH:MM:SS.

tmin_col

Name of minimum temperature column (daily data) (string)

temp_col

Name of temperature column (for single temp or hourly) (string)

Examples

Run this code
# Daily data with minimum temperature
daily_data <- data.frame(
  date = seq(as.Date("2000-01-01"), as.Date("2002-12-31"), by = "day"),
  tmin = rnorm(1096, mean = 5, sd = 5)
)

calculate_TN0(
  df = daily_data,
  frequency = "daily",
  time_col = "date",
  tmin_col = "tmin"
)

Run the code above in your browser using DataLab