Learn R Programming

tidyextreme (version 1.0.0)

calculate_TN10p: Calculate 10th percentile of daily temperature (TN10p)

Description

Calculates the 10th percentile of daily temperature per year, used as threshold for extreme cold nights.

Usage

calculate_TN10p(
  df,
  frequency = "daily",
  time_col = NULL,
  tmin_col = NULL,
  temp_col = NULL
)

Value

A tibble with columns: year, TN10p

Arguments

df

Data frame with climate data

frequency

Temporal frequency: "daily" or "hourly" (string)

time_col

Name of the time column (string). For daily frequency, the column should be of class Date or a string in the format YYYY-MM-DD. For hourly frequency, the column should be of class POSIXct or a string in the format YYYY-MM-DD HH:MM:SS.

tmin_col

Name of minimum temperature column (daily data) (string)

temp_col

Name of temperature column (for single temp or hourly) (string)

Examples

Run this code
# Daily data with minimum temperature
daily_data <- data.frame(
  date = seq(as.Date("2000-01-01"), as.Date("2002-12-31"), by = "day"),
  tmin = rnorm(1096, mean = 10, sd = 5)
)

calculate_TN10p(
  df = daily_data,
  frequency = "daily",
  time_col = "date",
  tmin_col = "tmin"
)

Run the code above in your browser using DataLab