Learn R Programming

tidyextreme (version 1.0.0)

calculate_TX30: Calculate number of days with temperature \(\geq\) 30\(^\circ\)C

Description

Counts the number of days per year when daily temperature is greater than or equal to 30\(^\circ\)C.

Usage

calculate_TX30(
  df,
  frequency = "daily",
  time_col = NULL,
  tmax_col = NULL,
  temp_col = NULL
)

Value

A tibble with columns: year, TX30

Arguments

df

Data frame with climate data

frequency

Temporal frequency: "daily" or "hourly"

time_col

Name of the time column. For daily frequency, the column should be of class Date or a string in the format YYYY-MM-DD. For hourly frequency, the column should be of class POSIXct or a string in the format YYYY-MM-DD HH:MM:SS.

tmax_col

Name of maximum temperature column (daily data)

temp_col

Name of temperature column (for single temp or hourly)

Examples

Run this code
# Daily data with maximum temperature
daily_data <- data.frame(
  date = seq(as.Date("2000-01-01"), as.Date("2002-12-31"), by = "day"),
  tmax = rnorm(1096, mean = 25, sd = 6)
)

calculate_TX30(
  df = daily_data,
  frequency = "daily",
  time_col = "date",
  tmax_col = "tmax"
)

Run the code above in your browser using DataLab