Learn R Programming

tidyextreme (version 1.0.0)

calculate_TX90p: Calculate 90th percentile of daily temperature (TX90p)

Description

Calculates the 90th percentile of daily temperature per year, used as threshold for extreme warm days.

Usage

calculate_TX90p(
  df,
  frequency = "daily",
  time_col = NULL,
  tmax_col = NULL,
  temp_col = NULL
)

Value

A tibble with columns: year, TX90p

Arguments

df

Data frame with climate data

frequency

Temporal frequency: "daily" or "hourly" (string)

time_col

Name of the time column (string). For daily frequency, the column should be of class Date or a string in the format YYYY-MM-DD. For hourly frequency, the column should be of class POSIXct or a string in the format YYYY-MM-DD HH:MM:SS.

tmax_col

Name of maximum temperature column (daily data) (string)

temp_col

Name of temperature column (for single temp or hourly) (string)

Examples

Run this code
# Daily data with maximum temperature
daily_data <- data.frame(
  date = seq(as.Date("2000-01-01"), as.Date("2002-12-31"), by = "day"),
  tmax = rnorm(1096, mean = 25, sd = 6)
)

calculate_TX90p(
  df = daily_data,
  frequency = "daily",
  time_col = "date",
  tmax_col = "tmax"
)

Run the code above in your browser using DataLab